@@ -44,7 +44,7 @@ except ImportError:
 
 from errors import raise_error
 
-BASE_URL = 'http://fluiddb.fluidinfo.com'
+BASE_URL = 'https://fluiddb.fluidinfo.com'
 NO_CONTENT = object()
 PRIMITIVE_CONTENT_TYPE = 'application/vnd.fluiddb.value+json'
 DESERIALIZABLE_CONTENT_TYPES = set((PRIMITIVE_CONTENT_TYPE, 'application/json'))
@@ -154,6 +154,10 @@ class FluidDB(object):
     """
 
     def __init__(self, base_url=BASE_URL):
+        if base_url.endswith('/'):
+            raise ValueError('The domain for FluidDB must *not* end with'\
+                             ' "/". Correct example:'\
+                             ' https://fluiddb.fluidinfo.com')
         self.base_url = base_url
         self.headers = {
             'User-agent': 'fom',
